﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using System.Windows.Shapes;

namespace TestProject
{
    /// <summary>
    /// 색상 리스트 박스 항목
    /// </summary>
    public class ColorListBoxItem : ListBoxItem
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 텍스트
        /// </summary>
        private string text;

        /// <summary>
        /// 사각형
        /// </summary>
        private Rectangle rectangle;

        /// <summary>
        /// 텍스트 블럭
        /// </summary>
        private TextBlock textBlock;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 텍스트 - Text

        /// <summary>
        /// 텍스트
        /// </summary>
        public string Text
        {
            set
            {
                this.text = value;

                string result = this.text[0].ToString();

                for(int i = 1; i < this.text.Length; i++)
                {
                    result += (char.IsUpper(this.text[i]) ? " " : "") + this.text[i].ToString();
                }

                this.textBlock.Text = result;
            }
            get
            {
                return this.text;
            }
        }

        #endregion
        #region 색상 - Color

        /// <summary>
        /// 색상
        /// </summary>
        public Color Color
        {
            set
            {
                this.rectangle.Fill = new SolidColorBrush(value);
            }
            get
            {
                SolidColorBrush solidColorBrush = this.rectangle.Fill as SolidColorBrush;

                return solidColorBrush == null ? Colors.Transparent : solidColorBrush.Color;
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - ColorListBoxItem()

        /// <summary>
        /// 생성자
        /// </summary>
        public ColorListBoxItem()
        {
            StackPanel stackPanel = new StackPanel();

            stackPanel.Orientation = Orientation.Horizontal;

            Content = stackPanel;

            this.rectangle = new Rectangle();

            this.rectangle.Width  = 16;
            this.rectangle.Height = 16;
            this.rectangle.Margin = new Thickness(2);
            this.rectangle.Stroke = SystemColors.WindowTextBrush;

            stackPanel.Children.Add(this.rectangle);

            this.textBlock = new TextBlock();

            this.textBlock.VerticalAlignment = VerticalAlignment.Center;
            this.textBlock.Margin            = new Thickness(2, 0, 0, 0);

            stackPanel.Children.Add(this.textBlock);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 문자열 구하기 - ToString()

        /// <summary>
        /// 문자열 구하기
        /// </summary>
        /// <returns>문자열</returns>
        public override string ToString()
        {
            return this.text;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 선택시 처리하기 - OnSelected(e)

        /// <summary>
        /// 선택시 처리하기
        /// </summary>
        /// <param name="e">이벤트 인자</param>
        protected override void OnSelected(RoutedEventArgs e)
        {
            base.OnSelected(e);

            this.textBlock.FontWeight = FontWeights.Bold;
        }

        #endregion
        #region 선택 해제시 처리하기 - OnUnselected(e)

        /// <summary>
        /// 선택 해제시 처리하기
        /// </summary>
        /// <param name="e">이벤트 인자</param>
        protected override void OnUnselected(RoutedEventArgs e)
        {
            base.OnUnselected(e);

            this.textBlock.FontWeight = FontWeights.Regular;
        }

        #endregion
    }
}